Turning on the screen when audio stream of an incoming call is directed through Bluetooth.

Bug: 70638560
Test: InCallActivityTest
PiperOrigin-RevId: 179261692
Change-Id: I269c8573592e6ff6083efc201e6bede74a01ee06
diff --git a/java/com/android/incallui/InCallActivity.java b/java/com/android/incallui/InCallActivity.java
index 47b5986..c4c365a 100644
--- a/java/com/android/incallui/InCallActivity.java
+++ b/java/com/android/incallui/InCallActivity.java
@@ -261,10 +261,11 @@
         WindowManager.LayoutParams.FLAG_SHOW_WHEN_LOCKED
             | WindowManager.LayoutParams.FLAG_IGNORE_CHEEK_PRESSES;
 
     // When the audio stream is not directed through Bluetooth, turn the screen on once the
     // activity is shown.
     final int audioRoute = getAudioRoute();
-    if (audioRoute != CallAudioState.ROUTE_BLUETOOTH) {
+    if (audioRoute != CallAudioState.ROUTE_BLUETOOTH
+        || CallList.getInstance().getIncomingCall() != null) {
       flags |= WindowManager.LayoutParams.FLAG_TURN_SCREEN_ON;
     }
@@ -261,10 +261,11 @@
             | WindowManager.LayoutParams.FLAG_IGNORE_CHEEK_PRESSES;
 
-    // When the audio stream is not directed through Bluetooth, turn the screen on once the
-    // activity is shown.
+    // When the audio stream is not via Bluetooth, turn on the screen once the activity is shown.
+    // When the audio stream is via Bluetooth, turn on the screen only for an incoming call.
     final int audioRoute = getAudioRoute();